@@ -29,8 +29,6 @@
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRegExpEditorInterface>
-#include <KServiceTypeTrader>
 #include <KSharedConfig>
 #include <KShell>
 #include <KUrlComboBox>
@@ -55,7 +53,6 @@ struct MimeTypes
 
 KfindTabWidget::KfindTabWidget(QWidget *parent)
     : QTabWidget(parent)
-    , regExpDialog(nullptr)
 {
     // This validator will be used for all numeric edit fields
     //KDigitValidator *digitV = new KDigitValidator(this);
@@ -159,9 +156,9 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
 
     connect(browseB, &QPushButton::clicked, this, &KfindTabWidget::getDirectory);
 
-    connect(nameBox, static_cast<void (KComboBox::*)()>(&KComboBox::returnPressed), this, &KfindTabWidget::startSearch);
+    connect(nameBox, QOverload<const QString &>::of(&KComboBox::returnPressed), this, &KfindTabWidget::startSearch);
 
-    connect(dirBox, static_cast<void (KUrlComboBox::*)()>(&KUrlComboBox::returnPressed), this, &KfindTabWidget::startSearch);
+    connect(dirBox, QOverload<const QString &>::of(&KUrlComboBox::returnPressed), this, &KfindTabWidget::startSearch);
 
     // ************ Page Two
 
@@ -294,7 +291,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     QLabel *textL = new QLabel(i18n("C&ontaining text:"), pages[2]);
     textL->setBuddy(textEdit);
 
-    connect(textEdit, &KLineEdit::returnPressed, this, &KfindTabWidget::startSearch);
+    connect(textEdit, &QLineEdit::returnPressed, this, &KfindTabWidget::startSearch);
 
     const QString containingtext
         = i18n("<qt>If specified, only files that contain this text"
@@ -307,7 +304,6 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
 
     caseContextCb = new QCheckBox(i18n("Case s&ensitive"), pages[2]);
     binaryContextCb = new QCheckBox(i18n("Include &binary files"), pages[2]);
-    regexpContentCb = new QCheckBox(i18n("Regular e&xpression"), pages[2]);
 
     const QString binaryTooltip
         = i18n("<qt>This lets you search in any type of file, "
@@ -315,13 +311,6 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
                "program files and images).</qt>");
     binaryContextCb->setToolTip(binaryTooltip);
 
-    QPushButton *editRegExp = nullptr;
-    if (!KServiceTypeTrader::self()->query(QStringLiteral("KRegExpEditor/KRegExpEditor")).isEmpty()) {
-        // The editor is available, so lets use it.
-        editRegExp = new QPushButton(i18n("&Edit..."), pages[2]);
-        editRegExp->setObjectName(QStringLiteral("editRegExp"));
-    }
-
     metainfokeyEdit = new KLineEdit(pages[2]);
     metainfoEdit = new KLineEdit(pages[2]);
     QLabel *textMetaInfo = new QLabel(i18nc("as in search for", "fo&r:"), pages[2]);
@@ -346,7 +335,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
         MimeTypes mimeTypes;
 
         const auto types = QMimeDatabase().allMimeTypes();
-        foreach (const QMimeType &type, types) {
+        for (const QMimeType &type : types) {
             if ((!type.comment().isEmpty())
                 && (!type.name().startsWith(QLatin1String("kdedevice/")))
                 && (!type.name().startsWith(QLatin1String("all/")))) {
@@ -387,15 +376,6 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
         watcher->deleteLater();
     });
 
-    if (editRegExp) {
-        // The editor was available, so lets use it.
-        connect(regexpContentCb, &QCheckBox::toggled, editRegExp, &QPushButton::setEnabled);
-        editRegExp->setEnabled(false);
-        connect(editRegExp, &QPushButton::clicked, this, &KfindTabWidget::slotEditRegExp);
-    } else {
-        regexpContentCb->hide();
-    }
-
     // Layout
     tmp = sizeEdit->fontMetrics().boundingRect(QStringLiteral(" 00000 ")).width();
     sizeEdit->setMinimumSize(tmp, sizeEdit->sizeHint().height());
@@ -405,7 +385,6 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     grid2->addWidget(textL, 1, 0);
     grid2->addWidget(typeBox, 0, 1, 1, 3);
     grid2->addWidget(textEdit, 1, 1, 1, 3);
-    grid2->addWidget(regexpContentCb, 2, 2);
     grid2->addWidget(caseContextCb, 2, 1);
     grid2->addWidget(binaryContextCb, 3, 1);
 
@@ -416,11 +395,6 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
 
     metainfokeyEdit->setText(QStringLiteral("*"));
 
-    if (editRegExp) {
-        // The editor was available, so lets use it.
-        grid2->addWidget(editRegExp, 2, 3);
-    }
-
     addTab(pages[0], i18n("Name/&Location"));
     addTab(pages[2], i18nc("tab name: search by contents", "C&ontents"));
     addTab(pages[1], i18n("&Properties"));
@@ -532,25 +506,6 @@ void KfindTabWidget::loadHistory()
     }
 }
 
-void KfindTabWidget::slotEditRegExp()
-{
-#if 0
-    if (!regExpDialog) {
-        regExpDialog = KServiceTypeTrader::createInstanceFromQuery<QDialog>(QStringLiteral("KRegExpEditor/KRegExpEditor"), QString(), this);
-    }
-
-    KRegExpEditorInterface *iface = qobject_cast<KRegExpEditorInterface *>(regExpDialog);
-    if (!iface) {
-        return;
-    }
-
-    iface->setRegExp(textEdit->text());
-    if (regExpDialog->exec()) {
-        textEdit->setText(iface->regExp());
-    }
-#endif
-}
-
 void KfindTabWidget::setFocus()
 {
     nameBox->setFocus();
@@ -706,13 +661,8 @@ void KfindTabWidget::setQuery(KQuery *query)
             const QDate &from = fromDate->date();
             const QDate &to = toDate->date();
             // do not generate negative numbers .. find doesn't handle that
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            time_t time1 = epoch.secsTo(QDateTime(from));
-            time_t time2 = epoch.secsTo(QDateTime(to.addDays(1))) - 1; // Include the last day
-#else
             time_t time1 = epoch.secsTo(QDateTime(from.startOfDay()));
             time_t time2 = epoch.secsTo(QDateTime(to.addDays(1).startOfDay())) - 1; // Include the last day
-#endif
 
             query->setTimeRange(time1, time2);
         } else {
@@ -776,8 +726,7 @@ void KfindTabWidget::setQuery(KQuery *query)
 
     query->setShowHiddenFiles(hiddenFilesCb->isChecked());
 
-    query->setContext(textEdit->text(), caseContextCb->isChecked(),
-                      binaryContextCb->isChecked(), regexpContentCb->isChecked());
+    query->setContext(textEdit->text(), caseContextCb->isChecked(), binaryContextCb->isChecked());
 }
 
 void KfindTabWidget::getDirectory()
